#
# spec file for package trader
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2012-22 John Zaitseff <J.Zaitseff@zap.org.au>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# ***********************************************************************
# *                                                                     *
# *            Star Traders: A Game of Interstellar Trading             *
# *               Copyright (C) 1990-2022, John Zaitseff                *
# *                                                                     *
# ***********************************************************************

# Author: John Zaitseff <J.Zaitseff@zap.org.au>
# $Id: 99f93cf1589a39d7579741fa302eb9e9818a2e5b $

# This file is distributed under the same licence as Star Traders itself:
# the GNU General Public License, version 3 or later.

%define upstream_version   7.18
%define normalised_version 7.18
%define rpm_release_num    1

Name:           trader
Version:        %{normalised_version}
Release:        1.5
Summary:        Star Traders, a simple game of interstellar trading
License:        GPL-3.0-or-later
Group:          Amusements/Games/Strategy/Turn Based
URL:            https://www.zap.org.au/projects/trader/

Source0:        https://ftp.zap.org.au/pub/trader/unix/trader-%{upstream_version}.tar.xz
Source1:        https://ftp.zap.org.au/pub/trader/unix/trader-%{upstream_version}.tar.xz.sig
# Source2 downloaded from https://www.zap.org.au/~john/pubkey.asc
Source2:        trader.keyring

BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  gperf
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(ncurses)

Requires(post): hicolor-icon-theme
Requires(postun):hicolor-icon-theme
Recommends:     %{name}-lang = %{version}

%description
Star Traders is a simple game of interstellar trading, where the objective
is to create companies, buy and sell shares, borrow and repay money, in
order to become the wealthiest player (the winner).

%lang_package

%prep
%setup -q -n %{name}-%{upstream_version}

%build
%configure
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name}
%suse_update_desktop_file %{name}

%files
%doc README NEWS
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man6/trader.6%{ext_man}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/icons/hicolor/*/apps/%{name}.*

%files lang -f %{name}.lang

%changelog
* Fri Aug  6 2021 John Zaitseff <J.Zaitseff@zap.org.au>
- New upstream release of Star Traders: version 7.18.
  * From version 7.17: fixed two TOCTOU (time-of-check / time-of-use)
    bugs between checking for traditional data directory and creating a
    data directory later.  Also fixed a bug when the HOME environment
    variable is empty.
  * From version 7.17: Updated Brazilian Portuguese, Norwegian Bokmål,
    Swedish, French, Esperanto, Serbian, German and English translations.
  * Removed the <icon> line from trader.appdata.xml so that the icon is
    taken from the trader.desktop file instead.
- Include trader.keyring to allow for upstream source verification.
- Remove prerelease conditional.
  * Prereleases haven't been used for over five years, nor is it expected
    that an openSUSE package will be made from one even if there is a
    future prerelease.
* Fri Apr 30 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 7.16
  * Added code to allow the ``TEXTDOMAINDIR`` environment variable
    to specify where compiled translations are located.
  * Added an application metadata file that conforms to the
    AppStream 0.12 specification.
  * Updated the German translation
- Update to version 7.15
  * Changed the default location where game files are saved
    from `~/.trader` to `~/.local/share/trader`, so as to follow
    the `XDG Base Directory Specification`
  * If set to an absolute path, the ``XDG_DATA_HOME`` environment
    variable will override this location.
  * If the `~/.trader` directory is already present, it will
    continue to be used.
  * Updated the Russian translation
* Thu Jan  9 2020 J.Zaitseff@zap.org.au
- New upstream release of Star Traders: version 7.14.
  * New Brazilian Portuguese translation
  * Updated French, Hungarian and Esperanto translations
* Wed Nov 27 2019 J.Zaitseff@zap.org.au
- Use %%license for the COPYING file.
* Fri Nov 15 2019 J.Zaitseff@zap.org.au
- Update the spec file to match the result of "osc build".
* Fri Nov 15 2019 J.Zaitseff@zap.org.au
- New upstream release of Star Traders: version 7.13.
  * Updated Esperanto translation
- Changed dependency from ncurses-devel to pkgconfig(ncurses), now
  that OpenSUSE 42.x is no longer relevant.
* Fri Jan  5 2018 avindra@opensuse.org
- New upstream release of Star Traders: version 7.12.
  * Updated Serbian translation
- cleanup with spec-cleaner
* Sun Jun 18 2017 J.Zaitseff@zap.org.au
- New upstream release of Star Traders: version 7.11.
* Tue Jun  6 2017 J.Zaitseff@zap.org.au
- Changed build dependency from pkgconfig(ncurses) back to ncurses-devel
  so that the package can build on OpenSUSE 42.x.
* Tue Jun  6 2017 J.Zaitseff@zap.org.au
- New upstream release of Star Traders: version 7.10.
- Make the lang package unconditional (assume suse_version >= 1100).
- Changed dependency from ncurses-devel to pkgconfig(ncurses), now that
  the Autoconf macro uses pkg-config.
- Added a dependency on gcc.
- Added a dependency on update-desktop-files for the desktop file.
- Install the desktop file and icons now shipped with Star Traders.
- Remove the clean section, as per current OpenSUSE packaging guidelines.
* Wed Jan  6 2016 J.Zaitseff@zap.org.au
- New upstream release of Star Traders: version 7.9.
* Fri Sep 11 2015 J.Zaitseff@zap.org.au
- New upstream release of Star Traders: version 7.8.
* Wed Aug 19 2015 J.Zaitseff@zap.org.au
- New upstream release of Star Traders: version 7.7.
* Thu Aug 14 2014 J.Zaitseff@zap.org.au
- New upstream release of Star Traders: version 7.6.
* Sun May 25 2014 J.Zaitseff@zap.org.au
- New upstream release of Star Traders: version 7.5.
* Thu May 10 2012 J.Zaitseff@zap.org.au
- New upstream release of Star Traders: version 7.4.
* Mon Apr 30 2012 J.Zaitseff@zap.org.au
- Updated the variable rpm_release_num to 3
- More tweaking just for the very pedantic "osc ci"
* Mon Apr 30 2012 J.Zaitseff@zap.org.au
- Updated the variable rpm_release_num to 2
- Added missing %%changelog section to RPM spec file
- Changed some RPM spec fields to match what "osc ci" requires
* Mon Apr 30 2012 J.Zaitseff@zap.org.au
- Made the RPM spec file more specific for OpenSUSE by removing
  Fedoraisms.
* Sun Apr 15 2012 J.Zaitseff@zap.org.au
- New upstream release of Star Traders: 7.4-pre2
* Fri Mar 30 2012 pth@suse.de
- Complete translation added.
* Fri Mar 30 2012 pth@suse.de
- Initial openSUSE package
- Add german translation and add de to po/LINGUAS
